@@ -224,6 +224,6 @@ async def on_message(message):
 
 try:
     print("Attempting to login to Discord...")
-    client.run(command_dict["discord_bot_token"])
+    client.run(f"{command_dict['discord_bot_token']}")
 except Exception as login_error:
     print(login_error)
